from rest_framework.serializers import ModelSerializer
from netbox_work_logs.models import Category, VMWorkLog, DeviceWorkLog


class CategorySerializer(ModelSerializer):

    class Meta:
        model = Category
        fields = ('id', 'category', 'category_label')

class VMWorkLogSerializer(ModelSerializer):
    
    class Meta:
        model = VMWorkLog
        fields = ('id', 'vm', 'user', 'category', 'subject', 'content', 'internal_only', 'ticket_id', 'time')
        
    def create(self, validated_data):
        return VMWorkLog.objects.create(**validated_data)

class DeviceWorkLogSerializer(ModelSerializer):
    
    class Meta:
        model = DeviceWorkLog
        fields = ('id', 'device', 'user', 'category', 'subject', 'content', 'internal_only', 'ticket_id', 'time')



from rest_framework import routers

from .views import CategoryViewSet, VMWorkLogViewSet, DeviceWorkLogViewSet, WorkLogsRootView


router = routers.DefaultRouter()
router.APIRootView = WorkLogsRootView

router.register('categories', CategoryViewSet)
router.register('vm-logs', VMWorkLogViewSet)
router.register('device-logs', DeviceWorkLogViewSet)

app_name = 'netbox_work_logs-api'
urlpatterns = router.urls



from rest_framework import status
from rest_framework.viewsets import ModelViewSet
from rest_framework.routers import APIRootView
from rest_framework.response import Response
from netbox_work_logs.models import Category, VMWorkLog, DeviceWorkLog
from .serializers import CategorySerializer, VMWorkLogSerializer, DeviceWorkLogSerializer
from netbox_work_logs import filters
class WorkLogsRootView(APIRootView):
    """
    WorkLogs API root view
    """
    def get_view_name(self):
        return 'Work Logs'

# 
# Categories
# 

class CategoryViewSet(ModelViewSet):
    queryset = Category.objects.all()
    serializer_class = CategorySerializer
    

# 
# VM Work Logs
# 

class VMWorkLogViewSet(ModelViewSet):
    queryset = VMWorkLog.objects.all()
    serializer_class = VMWorkLogSerializer
    filterset_class = filters.VMWorkLogFilterSet
    
    def create(self, request, *args, **kwargs):
        data = request.POST
        serializer = self.get_serializer(data=data)
        
        if serializer.is_valid():
            serializer.save()
            return Response(serializer.data)
        return Response(serializer.errors, status=status.HTTP_400_BAD_REQUEST)
        

# 
# Device Work Logs
# 

class DeviceWorkLogViewSet(ModelViewSet):
    queryset = DeviceWorkLog.objects.all()
    serializer_class = DeviceWorkLogSerializer
    filterset_class = filters.DeviceWorkLogFilterSet
    
    def create(self, request, *args, **kwargs):
        data = request.POST
        serializer = self.get_serializer(data=data)
        
        if serializer.is_valid():
            serializer.save()
            return Response(serializer.data)
        return Response(serializer.errors, status=status.HTTP_400_BAD_REQUEST)



from utilities.choices import ChoiceSet

class InternalOnlyChoices(ChoiceSet):
    INTERNAL_ONLY_YES = True
    INTERNAL_ONLY_NO = False
    
    CHOICES = (
        (INTERNAL_ONLY_YES, 'true'),
        (INTERNAL_ONLY_NO, 'false')
    )
